@@ -37,6 +37,9 @@ class Fond(QGraphicsView):
     def resizeEvent ( self, event ):
         self.emit(SIGNAL("resized()"))
 
+    def mousePressEvent(self,event):
+        self.emit(SIGNAL("pressed()"))
+        QGraphicsView.mousePressEvent (self, event)
         
     def mouseDoubleClickEvent(self, event):
         self.dblClicked = True
@@ -125,9 +128,18 @@ class Fond(QGraphicsView):
 #CARTE  = Scene   
 
 class Carte(QGraphicsScene):
+    fond = QGraphicsRectItem ()
+    fond.setBrush(QBrush(QColor(0,0,0,153)))
 
     def doubleClick  ( self, p ):
         self.emit(SIGNAL("dblclicked(QPointF)"),p)
+        
+    def blur(self):
+        self.fond.setRect(self.sceneRect())
+        self.addItem(self.fond)
+
+    def unblur(self):
+        self.removeItem(self.fond)
 
 
       
@@ -347,52 +359,227 @@ class Gps(QGraphicsEllipseItem):
         gradient.setColorAt(1, Qt.black)
         gradient.setColorAt(0, Qt.red)
         self.setPen(QPen(gradient, _RAYON))
+        
+        
 
-class diagLigne(QDialog):   
-    def __init__(self, already, parent=None):
+class diagAmbig(QWidget):   
+    def __init__(self, liste, parent=None):
+        super(diagSearch, self).__init__(parent)
+        self.hide()
+        self.setGeometry(0,0,parent.width(),400)
+        self.Layout = QVBoxLayout(self)
+        
+        self.Line = QListWidget(self)
+
+        self.Line.setStyleSheet("border-left:8px solid white; color: white;")
+        self.Line.setGeometry(self.width()/2-150,40,300,48)
+
+
+class diagLigne(QWidget):   
+    def __init__(self, already, portrait, parent=None):
         super(diagLigne, self).__init__(parent)
 
+        self.hide()
+        QObject.connect(self.parent(), SIGNAL("pressed()"), self.close)
 
-        self.setWindowTitle("Rtap : Lignes")
-        self.resize(800,400)
-        self.Layout = QGridLayout(self)
+        self.Layout = QVBoxLayout(self)
+
+        self.LayoutBouton = QHBoxLayout()
+        self.Metro = QPushButton("M",self)
+        self.Metro.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
+        self.Metro.setMaximumSize(72,72)
+        self.Metro.setCheckable(True)
+        self.Metro.setStyleSheet("QPushButton {font: bold 32px;border:8px solid white;color:white;border-radius: 35px;} QPushButton:checked {background-color: white;color:black;}")
+        self.LayoutBouton.addWidget(self.Metro)
         
-        self.List = QListWidget(self)
-        self.List.setSelectionMode(QAbstractItemView.MultiSelection)
+        self.Rer = QPushButton("R",self)
+        self.Rer.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
+        self.Rer.setMaximumSize(72,72)
+        self.Rer.setCheckable(True)
+        self.Rer.setStyleSheet("QPushButton {font: bold 32px;border:8px solid white;color:white;border-radius: 35px;} QPushButton:checked {background-color: white;color:black;}")
+        self.LayoutBouton.addWidget(self.Rer)
         
-#        for line in ['Metro 1','Metro 2', 'Metro 3', 'Metro 4', 'Metro 5', 'Metro 6', 'Metro 7', 'Metro 8', 'Metro 9', 'Metro 10', 'Metro 11', 'Metro 12', 'Metro 13', 'Metro 14', 'Metro 3b', 'Metro 7b', 'Rer A', 'Rer B', 'Rer D', 'Rer E']:
-        for line in ["Metro","RER","Tram"]:
-            self.List.addItem(line)
-
-#        for row in already:
-#            self.List.item(row).setSelected ( True)
-
-
-#        find = self.diagList.findItems ( self.Type.text(), QtCore.Qt.MatchContains ) 
-#        if find != []:
-#            self.diagList.setCurrentItem', '(find[0])
-#        else:
-#            self.diagList.addItem(self.Type.text())
-#            self.diagList.setCurrentRow(self.diagList.count() - 1)
-       
-        self.Ok = QPushButton("Ok",self)
         self.Tout = QPushButton("Tout",self)
-        self.Aucun = QPushButton("Aucun",self)
+        self.Tout.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
+        self.Tout.setMaximumSize(96,72)
+        self.Tout.setStyleSheet("QPushButton {font: bold 32px;border:8px solid white;color:black;border-radius: 35px;background-color: white;} QPushButton:pressed {background-color: blue;border-color:blue;}")
+        self.LayoutBouton.addWidget(self.Tout)
         
-        self.Layout.addWidget(self.List,0,0,1,3)
-        self.Layout.addWidget(self.Ok,1,2,1,1)
-        self.Layout.addWidget(self.Aucun,1,1,1,1)
-        self.Layout.addWidget(self.Tout,1,0,1,1)
+        self.Aucun = QPushButton("Rien",self)
+        self.Aucun.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
+        self.Aucun.setMaximumSize(96,72)
+        self.Aucun.setStyleSheet("QPushButton {font: bold 32px;border:8px solid white;color:white;border-radius: 35px;} QPushButton:pressed {color:red;border-color:red;}")
+        self.LayoutBouton.addWidget(self.Aucun)
+        
+        self.Tout.clicked.connect(self.selectAll)
+        self.Aucun.clicked.connect(self.selectNone)
+        self.Metro.toggled.connect(self.selectMetro)
+        self.Rer.toggled.connect(self.selectRer)
+        
+        self.LayoutMetro = QGridLayout()
+        self.Layout.addLayout(self.LayoutMetro)
+        if portrait:
+            self.buildMetro(4)
+            self.setGeometry(10,44,460,600)
+        else:
+            self.buildMetro(8)
+            self.setGeometry(100,00,600,440)
 
-        self.Ok.clicked.connect(self.close)
-        self.Tout.clicked.connect(self.List.selectAll)
-        self.Aucun.clicked.connect(self.List.clearSelection)
+        self.LayoutRer = QHBoxLayout()
+        self.Layout.addLayout(self.LayoutRer)
+        i=0
+        lettre = ["A","B","C","D","E"]
+        for color in [station.RERA,station.RERB,station.RERC,station.RERD,station.RERE]:
+            boutton = QPushButton(lettre[i],self)
+            boutton.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
+            boutton.setMaximumSize(64,64)
+            boutton.setCheckable(True)
+            boutton.setStyleSheet("QPushButton {border-radius: 32px;font: bold 32px;border:8px solid "+color.name()+";color:"+color.name()+";} QPushButton:checked {background-color: "+color.name()+";color:white;}")
+            self.LayoutRer.addWidget(boutton)
+            i += 1
+
+        i = 0
+        self.LayoutTram = QHBoxLayout()
+        self.Layout.addLayout(self.LayoutTram)
+        lettre = ["T1","T2","T3","T4"]
+        for color in [station.LigneT1,station.LigneT2,station.LigneT3,station.LigneT4]:
+            boutton = QPushButton(lettre[i],self)
+            boutton.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
+            boutton.setMaximumSize(64,64)
+            boutton.setCheckable(True)
+            boutton.setStyleSheet("QPushButton {border-radius: 32px;font: bold 32px;border:8px solid "+color.name()+";color:"+color.name()+";} QPushButton:checked {background-color: "+color.name()+";color:white;}")
+            self.LayoutTram.addWidget(boutton)
+            i += 1
+        self.Layout.addLayout(self.LayoutBouton)
+
+        i=0
+        j=0
+        for idx in already:
+            if idx < 16:
+                self.LayoutMetro.itemAt(idx).widget().setChecked(True)
+                i += idx
+            elif idx < 21:
+                self.LayoutRer.itemAt(idx-16).widget().setChecked(True)
+                j+=idx
+            else:
+                self.LayoutTram.itemAt(idx-21).widget().setChecked(True)
+        if i == 120:
+            self.Metro.setChecked(True)
+        if j == 90:
+            self.Rer.setChecked(True)
+            
+#######Construction
+    def buildMetro(self,N):
+        i = 0       
+        for color in [station.Ligne1,station.Ligne2,station.Ligne3,station.Ligne4,station.Ligne5,station.Ligne6,station.Ligne7,station.Ligne8,station.Ligne9,station.Ligne10,station.Ligne11,station.Ligne12,station.Ligne13,station.Ligne14,station.Ligne3b,station.Ligne7b]:
+            button = QPushButton(str(i+1),self)
+            if i == 14:
+                button.setText('3b')
+            elif i == 15:
+                button.setText('7b')
+            button.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum))
+            button.setMaximumSize(64,64)
+            button.setCheckable(True)
+            button.setStyleSheet("QPushButton {font: bold 32px;border:8px solid "+color.name()+";color:"+color.name()+";border-radius: 32px;} QPushButton:checked {background-color: "+color.name()+";color:white;}")
+            self.LayoutMetro.addWidget(button,i/N,i % N)
+            i += 1
+              
+    def selectMetro(self,b):
+        for j in range(16):
+            self.LayoutMetro.itemAt(j).widget().setChecked(b)
+
+    def selectRer(self,b):
+        for j in range(5):
+            self.LayoutRer.itemAt(j).widget().setChecked(b)
+
+
+    def selectAll(self):
+        self.Metro.setChecked(True)
+        self.Rer.setChecked(True)
+        for idx in range(25):
+            if idx < 16:
+                self.LayoutMetro.itemAt(idx).widget().setChecked(True)
+            elif idx < 21:
+                self.LayoutRer.itemAt(idx-16).widget().setChecked(True)
+            else:
+                self.LayoutTram.itemAt(idx-21).widget().setChecked(True)
+
+    def selectNone(self):
+        self.Metro.setChecked(False)
+        self.Rer.setChecked(False)
+        for idx in range(25):
+            if idx < 16:
+                self.LayoutMetro.itemAt(idx).widget().setChecked(False)
+            elif idx < 21:
+                self.LayoutRer.itemAt(idx-16).widget().setChecked(False)
+            else:
+                self.LayoutTram.itemAt(idx-21).widget().setChecked(False)
+   
+    def orientation(self):
+        if self.LayoutMetro.columnCount() == 8:
+            for idx in range(16):
+                self.LayoutMetro.itemAt(idx).widget().deleteLater()
+            self.buildMetro(4)
+            self.setGeometry(10,44,460,600)
+        else:
+            for idx in range(16):
+                self.LayoutMetro.itemAt(idx).widget().deleteLater()
+            self.buildMetro(8)
+            self.setGeometry(100,00,600,440)
 
     def closeEvent(self,event):
         selec = []
-        for it in self.List.selectedItems():
-            selec.append(self.List.row(it))
-#        print selec
+        for idx in range(25):
+            if idx < 16:
+                if self.LayoutMetro.itemAt(idx).widget().isChecked():
+                    selec.append(idx)
+            elif idx < 21:
+                if self.LayoutRer.itemAt(idx-16).widget().isChecked():
+                    selec.append(idx)
+            else:
+                if self.LayoutTram.itemAt(idx-21).widget().isChecked():
+                    selec.append(idx)
         self.emit(SIGNAL("selection(PyQt_PyObject)"),selec)
-#        print 'closing'
-        QDialog.closeEvent (self, event)
+        QObject.disconnect(self.parent(), SIGNAL("pressed()"), self.close)
+        QWidget.closeEvent (self, event)
+
+        
+
+class diagAbout(QWidget):   
+    def __init__(self, parent=None):
+        super(diagAbout, self).__init__(parent)
+#        self.setWindowTitle("Rtap : \xc0 Propos")
+        self.setGeometry(100,60,600,300)
+
+        self.Layout = QGridLayout(self)
+        self.Titre = QLabel(' Rtap ',self)
+        self.Titre.setFont(QFont('Nokia Sans',48))
+        self.Titre.setSizePolicy(QSizePolicy(QSizePolicy.Maximum, QSizePolicy.Fixed))
+        self.Logo = QLabel(self)
+        self.Logo.setPixmap(QPixmap("/usr/share/pixmaps/Rtap_About.png"))
+        self.Logo.setAlignment(Qt.AlignCenter)
+        self.Text = QLabel(''', les transports \xe0 Paris sur le N900 avec les doigts!
+
+(C) 2011 LGPL
+Ahc\xe8ne 'Opax' Boubekki
+opax.gm@gmail.com
+Veuillez reporter les bugs \xe0 la m\xeame adresse, merci!''',self)
+        self.Text.setFont(QFont('Nokia Sans',18))
+        self.Text.setWordWrap(True)
+        
+        self.Layout.addWidget(self.Titre,0,0)
+        self.Layout.addWidget(self.Logo,1,0)
+        self.Layout.addWidget(self.Text,0,1,2,1)
+
+        self.Fond = QGraphicsRectItem (parent.sceneRect())
+        self.Fond.setBrush(QBrush(QColor(0,0,0,153)))
+        
+    def draw(self):
+        QObject.connect(self.parent(), SIGNAL("pressed()"), self.close)
+        self.parent().scene().blur()
+        self.show()
+        
+    def close ( self ):
+        QObject.disconnect(self.parent(), SIGNAL("pressed()"), self.close)
+        self.parent().scene().unblur()
+        self.hide()
