@@ -3,21 +3,13 @@
 
 from PyQt4.QtGui import *
 from PyQt4.QtCore import *
-from PyQt4.QtXml import *
 from PyQt4.QtMaemo5 import *
 from PyQt4.QtMobility.QtLocation import *
 from PyQt4.QtMobility.QtBearer import *
 
-#from connectivityhelper import ConnectivityHelper
-
 import station
-import math
-import os
 import dijkstra
 import classes
-import station
-
-import time
 
 _RAYON = station._RAYON
 _TEMPS_ANIM = 1000
@@ -86,7 +78,7 @@ class Ui_MainWindow(QMainWindow):
             self.m_latitude = coord.latitude()
             self.m_longitude = coord.longitude()
             self.gps.setPos( (self.m_longitude*10-20)*500,-(self.m_latitude*10-488)*700)
-            graph["GPS"].setPos(self.m_longitude, self.m_latitude)
+            graph["GPS"].setPosXY(self.m_longitude, self.m_latitude)
             if gpsPos.attribute(QGeoPositionInfo.HorizontalAccuracy) < 80 or gpsPos.attribute(QGeoPositionInfo.VerticalAccuracy) < 80:
                 self.gpsButton.setPix('Good')
             else:
@@ -125,7 +117,7 @@ class Ui_MainWindow(QMainWindow):
             animCenter.setDuration(_TEMPS_ANIM*2)
             animCenter.setEasingCurve(QEasingCurve.OutQuad)
             animCenter.setKeyValueAt(0, self.view.getCenter())
-            animCenter.setKeyValueAt(1, QPointF(  graph[self.Chemin[0]].posX,  graph[self.Chemin[0]].posY ))
+            animCenter.setKeyValueAt(1, QPointF(  graph[self.Chemin[0]].x(),  graph[self.Chemin[0]].y() ))
 
 
             #Anime Zoom    
@@ -150,8 +142,8 @@ class Ui_MainWindow(QMainWindow):
                 anim = QPropertyAnimation (self.view, "center")
                 anim.setDuration(_TEMPS_ANIM)
                 anim.setEasingCurve(QEasingCurve.InOutCubic)
-                anim.setKeyValueAt(0, QPointF(  graph[self.Chemin[i-1]].posX,  graph[self.Chemin[i-1]].posY )  )
-                anim.setKeyValueAt(1, QPointF(  graph[self.Chemin[i]].posX,  graph[self.Chemin[i]].posY )  )
+                anim.setKeyValueAt(0, graph[self.Chemin[i-1]].pos()  )
+                anim.setKeyValueAt(1, graph[self.Chemin[i]].pos()  )
                 self.view.animSeq.addAnimation(anim)
                 i += 1
     
@@ -161,19 +153,13 @@ class Ui_MainWindow(QMainWindow):
             animUnCenter = QPropertyAnimation (self.view, "center")
             animUnCenter.setDuration(_TEMPS_ANIM*2)
             animUnCenter.setEasingCurve(QEasingCurve.OutQuad)
-            animUnCenter.setKeyValueAt(0, QPointF(  graph[self.Chemin[-1]].posX,  graph[self.Chemin[-1]].posY ))
+            animUnCenter.setKeyValueAt(0, graph[self.Chemin[-1]].pos())
             
-            dx = abs(graph[self.Chemin[-1]].posX - graph[self.Chemin[0]].posX)
-            dy = abs(graph[self.Chemin[-1]].posY - graph[self.Chemin[0]].posY)
-            if graph[self.Chemin[-1]].posX - graph[self.Chemin[0]].posX > 0:
-                x = graph[self.Chemin[0]].posX + dx/2
-            else:
-                x = graph[self.Chemin[0]].posX - dx/2
-
-            if graph[self.Chemin[-1]].posY - graph[self.Chemin[0]].posY > 0:
-                y = graph[self.Chemin[0]].posY + dy/2
-            else:
-                y = graph[self.Chemin[0]].posY - dy/2 
+            dx = abs(graph[self.Chemin[-1]].x() - graph[self.Chemin[0]].x())
+            dy = abs(graph[self.Chemin[-1]].y() - graph[self.Chemin[0]].y())
+            
+            x = (graph[self.Chemin[-1]].x() + graph[self.Chemin[0]].x())/2
+            y = (graph[self.Chemin[-1]].y() + graph[self.Chemin[0]].y())/2
             animUnCenter.setKeyValueAt(1, QPointF(  x,  y ))
 
             #Anime UnZoom    
@@ -244,24 +230,30 @@ class Ui_MainWindow(QMainWindow):
                         self.gpsCenter()
                     
     def selecLignes(self):
-#        value, ok = QInputDialog.getItem ( self.view, "Rtap : Lignes", "Selectionnez les lignes que vous voulez afficher.", const QStringList & items, int current = 0, bool editable = true, bool * ok = 0, Qt::WindowFlags flags = 0 )
+        self.stop()
+        self.deselec(self.Selec[1])
+        self.deselec(self.Selec[0])
+
         graph.clear()
-        fullList = station.Metro + station.Rer + station.Tram
-        liste = []
-#        for line in self.Lignes[1:]:
-#            liste.append(fullList.index(line))
-        diag = classes.diagLigne(liste,self.view)
+        boole = (app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height())
+        diag = classes.diagLigne(self.Lignes,boole,self.view)
         QObject.connect(diag,SIGNAL("selection(PyQt_PyObject)"),self.selecLignesProcess)
+        QObject.connect(app.desktop(), SIGNAL("resized(int)"), diag.orientation)
+        self.scene.blur()
         diag.show()
         
     def selecLignesProcess(self,liste):
         reload(station)
-        self.Lignes = [station.GPS]
-        fullList = station.Metro,station.Rer,station.Tram
-        for it in liste:
-            self.Lignes += fullList[it]
+        self.Lignes = liste
         self.buildGraph()
         self.drawGraph()
+        if len(self.Lignes) < 5:
+            for stop in graph:
+                if stop[-1] != ']':
+                    nom = QGraphicsTextItem (stop,graph[stop])
+                    nom.setFont(QFont ( "Nokia Sans",_RAYON/2  ,63 ))
+                    nom.setDefaultTextColor(graph[stop].color.color().lighter())
+        self.scene.unblur()
 
     def setSelec(self,Name):
         
@@ -276,7 +268,7 @@ class Ui_MainWindow(QMainWindow):
                 self.gps.deselec()
                 for item in self.CheminItem:
                     self.scene.removeItem(item)
-                self.scene.removeItem(self.rectCalc)
+                self.scene.unblur()
                 self.panDepart.playX(w)
                 self.panArrivee.playX(w)
                 self.panAction.playX(w)
@@ -362,10 +354,10 @@ class Ui_MainWindow(QMainWindow):
     def deselec(self,Nom):
         w = self.width()
         h = self.height()
-        self.scene.removeItem(self.rectCalc)
+        self.scene.unblur()
         for item in self.CheminItem:
             self.scene.removeItem(item)
-        
+        self.Temps.hide()
         
         
         for value in graph:
@@ -389,8 +381,7 @@ class Ui_MainWindow(QMainWindow):
         
         
     def colorise(self):
-        t0= time.time()
-        self.scene.addItem(self.rectCalc)
+        self.scene.blur()
         self.CheminItem = []
         if self.Selec[0] == 'GPS':
             proche = self.gpsSearch(self.gps.pos())
@@ -405,23 +396,21 @@ class Ui_MainWindow(QMainWindow):
         else:
             self.Chemin, tps = dijkstra.algo(self.Selec[0],self.Selec[1],graph)
 
-#        print 'tps de calcul', time.time() - t0
-
         dep = self.Chemin[0]
         for dest in self.Chemin[1:]:
             idx = graph[dep].corres.index(dest)
             line = QGraphicsLineItem ( 
-                    graph[dep].posX + _RAYON/2, 
-                    graph[dep].posY + _RAYON/2, 
-                    graph[dest].posX + _RAYON/2, 
-                    graph[dest].posY + _RAYON/2, 
+                    graph[dep].x() + _RAYON/2, 
+                    graph[dep].y() + _RAYON/2, 
+                    graph[dest].x() + _RAYON/2, 
+                    graph[dest].y() + _RAYON/2, 
                     )
             line.setPen(QPen(graph[dep].corresColor[idx], _RAYON/2))
             self.CheminItem.append(line)
             dep = dest
         dep = self.Chemin[0]
         for dest in self.Chemin:
-            gradient = QRadialGradient(graph[dest].posX,graph[dest].posY, _RAYON*1.5)
+            gradient = QRadialGradient(graph[dest].x(),graph[dest].y(), _RAYON*1.5)
             try:
                 idx = graph[dest].corres.index(dep)
 
@@ -434,7 +423,7 @@ class Ui_MainWindow(QMainWindow):
                 gradient.setColorAt(0, graph[dest].color.color())
                 gradient.setColorAt(1, graph[dest].color.color())
                 
-            ellipse = QGraphicsEllipseItem (graph[dest].posX, graph[dest].posY, _RAYON, _RAYON)
+            ellipse = QGraphicsEllipseItem (graph[dest].x(), graph[dest].y(), _RAYON, _RAYON)
 
             ellipse.setPen(QPen( gradient, _RAYON/2))
             ellipse.setBrush(QBrush(gradient))
@@ -442,12 +431,12 @@ class Ui_MainWindow(QMainWindow):
             dep = dest
         dep = self.Chemin[0]
         for dest in self.Chemin:
-            if not graph[dest].name[:-4] in graph[dep].name or dest == dep:
-                if graph[dest].name[-1] == ']':
-                    txt = QGraphicsTextItem (graph[dest].name[:-4])
+            if not dest[:-4] in graph[dep].name or dest == dep:
+                if dest[-1] == ']':
+                    txt = QGraphicsTextItem (dest[:-4])
                 else:
-                    txt = QGraphicsTextItem (graph[dest].name)
-                txt.setPos(graph[dest].posX , graph[dest].posY-_RAYON/2)
+                    txt = QGraphicsTextItem (dest)
+                txt.setPos(graph[dest].pos())
                 txt.setFont(QFont ( "Nokia Sans",_RAYON/2 ,63 ))
     
                 try:
@@ -459,11 +448,11 @@ class Ui_MainWindow(QMainWindow):
                 except AttributeError:
                     txt.setDefaultTextColor(graph[dest].color.color())
                     
-                if graph[dest].name[-1] == ']':
-                    txtOmbre = QGraphicsTextItem (graph[dest].name[:-4])
+                if dest[-1] == ']':
+                    txtOmbre = QGraphicsTextItem (dest[:-4])
                 else:
-                    txtOmbre = QGraphicsTextItem (graph[dest].name)
-                txtOmbre.setPos(graph[dest].posX-.25, graph[dest].posY-_RAYON/2+.25)
+                    txtOmbre = QGraphicsTextItem (dest)
+                txtOmbre.setPos(graph[dest].x()-.25, graph[dest].y()+.25)
                 txtOmbre.setDefaultTextColor(Qt.black)
                 txtOmbre.setFont(QFont ( "Nokia Sans",_RAYON/2 ,63 ))
     
@@ -475,6 +464,14 @@ class Ui_MainWindow(QMainWindow):
             self.scene.addItem(item)
         self.scene.update()
         self.panAction.toggling()
+
+        self.Temps.setText("Environ "+ str(int(tps/60)) + " min.")
+        self.Temps.resize(200,40)
+        self.Temps.show()
+        self.animTemps.setKeyValueAt(0, QPoint(10, -50) )
+        self.animTemps.setKeyValueAt(1, QPoint(10, 0) )
+        self.animTemps.start()
+
         try:
             graph[str(proche)].removeCorres("GPS")
         except UnboundLocalError:
@@ -496,17 +493,26 @@ class Ui_MainWindow(QMainWindow):
         if self.panAction.state :
             self.panAction.move(app.desktop().screenGeometry().width()-100,self.panAction.y())
             self.panAction.animMargin.start()
+        if app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height():
+            self.about.setGeometry(10,144,460,400)       
+        else:
+            self.about.setGeometry(100,60,600,340)
+#        if self.panAction.toggle :  
+#            x = (app.desktop().screenGeometry().width() - self.Temps.width())/2
+#            self.Temps.move(x,app.desktop().screenGeometry().height() - 80 - 56)
 
     def buildGraph(self):
         toFix = []
         graph.clear()
-        for ligne in self.Lignes:
+        for it in self.Lignes:
+            ligne = station.FullListe[it]
             for stop in ligne:
                 if stop in graph:
                     for dest in ligne[stop].corres:
                         graph[stop].addCorres(dest,ligne[stop].color.color())
                 else:
                     graph[stop] = ligne[stop]
+        graph['GPS'] = station.GPS['GPS']
 
         
     def drawGraph(self):
@@ -521,10 +527,10 @@ class Ui_MainWindow(QMainWindow):
                 dest = graph[dep].corres[k]
                 try:
                     self.scene.addLine ( 
-                        graph[dep].posX + _RAYON/2, 
-                        graph[dep].posY + _RAYON/2, 
-                        graph[dest].posX + _RAYON/2, 
-                        graph[dest].posY + _RAYON/2, 
+                        graph[dep].x() + _RAYON/2, 
+                        graph[dep].y() + _RAYON/2, 
+                        graph[dest].x() + _RAYON/2, 
+                        graph[dest].y() + _RAYON/2, 
                         QPen(graph[dep].corresColor[k], _RAYON/4)
                         )        
                 except KeyError:
@@ -542,13 +548,15 @@ class Ui_MainWindow(QMainWindow):
         #Stations
         for value in graph:
             try:
-                if graph[value].name[-1] != "]" and graph[value].name != 'GPS':
+                if value[-1] != "]" and value != 'GPS':
                     self.scene.addItem(graph[value])
+                       
             except IndexError:
                 self.scene.addItem(graph[value])
         #Gps
         if self.gps.state:
             self.scene.addItem(self.gps)
+
                 
     def drawFleuve(self):
         #Fleuve
@@ -594,20 +602,7 @@ class Ui_MainWindow(QMainWindow):
         self.Selec = ('','')
         self.CheminItem = []
         self.Chemin = []
-        self.Lignes = [station.GPS] + station.Metro + station.Rer+ station.Tram
-
-
-        menubar = QMenuBar(self)
-        self.setMenuBar(menubar)
-        
-        menuChercher = QAction("Recherche",self)
-        menubar.addAction(menuChercher)
-        QObject.connect(menuChercher, SIGNAL("triggered()"), self.search)
-
-        menuLignes = QAction("Lignes",self)
-        menubar.addAction(menuLignes)
-        QObject.connect(menuLignes, SIGNAL("triggered()"), self.selecLignes)
-
+        self.Lignes = range(25)#[station.GPS] + station.Metro + station.Rer+ station.Tram
 
 
 ########## GPS
@@ -631,9 +626,6 @@ class Ui_MainWindow(QMainWindow):
         self.view.setVerticalScrollBarPolicy ( Qt.ScrollBarAlwaysOff )
         self.view.setHorizontalScrollBarPolicy ( Qt.ScrollBarAlwaysOff )
 
-        self.rectCalc = QGraphicsRectItem (self.view.sceneRect())
-        self.rectCalc.setBrush(QBrush(QColor(0,0,0,153)))
-
 ########## Panneaux
 
         self.panDepart = classes.PanStation(self.view)
@@ -654,6 +646,12 @@ class Ui_MainWindow(QMainWindow):
         self.panAction.show()
         self.panAction.animMargin.start()
         
+########## Temps
+        self.Temps = QLabel(self.view)
+        self.animTemps = QPropertyAnimation (self.Temps, "pos")
+        self.animTemps.setDuration(_TEMPS_ANIM/3)
+        self.animTemps.setEasingCurve(QEasingCurve.OutQuad)
+        
 ########## GPS Button
 
         self.gpsButton = classes.GpsButton(self.view)
@@ -664,12 +662,33 @@ class Ui_MainWindow(QMainWindow):
         self.gpsButton.setGeometry(16,app.desktop().screenGeometry().height()-80-56,80,80)
         self.gpsButton.show()
 
+######### Menu
+
+        menubar = QMenuBar(self)
+        self.setMenuBar(menubar)
+        
+        menuChercher = QAction("Recherche",self)
+        menubar.addAction(menuChercher)
+        QObject.connect(menuChercher, SIGNAL("triggered()"), self.search)
+
+        menuLignes = QAction("Lignes",self)
+        menubar.addAction(menuLignes)
+        QObject.connect(menuLignes, SIGNAL("triggered()"), self.selecLignes)
+
+        menuAbout = QAction("\xc0 Propos",self)
+        menubar.addAction(menuAbout)
+        self.about = classes.diagAbout(self.view)
+        self.about.hide()
+        QObject.connect(menuAbout, SIGNAL("triggered()"), self.about.draw)
+
 #########
 
         if app.desktop().screenGeometry().width() < app.desktop().screenGeometry().height():
-            self.view.centerOn(1900.,-500)        
+            self.view.centerOn(1900.,-500) 
+            self.about.setGeometry(10,144,460,400)       
         else:
             self.view.centerOn(1750.,-400)
+            self.about.setGeometry(100,60,600,340)
         self.view.show()
         self.view.update()
 
